==> flame_spatial_grid-0.8.1.tar.gz: lib/flame_spatial_grid.dart <==
library flame_spatial_grid;

export 'src/collisions/bounding_hitbox.dart';
export 'src/collisions/broadphase.dart' hide ScheduledHitboxOperation;
export 'src/collisions/collision_detection.dart';
export 'src/collisions/group_hitbox.dart';
export 'src/components/animation_global/animation_global_component.dart';
export 'src/components/animation_global/ticker_global.dart';
export 'src/components/animation_global/tickers_manager.dart';
export 'src/components/camera_wrapper.dart';
export 'src/components/has_grid_support.dart';
export 'src/components/layers/cell_layer.dart';
export 'src/components/layers/cell_static_animation_layer.dart';
export 'src/components/layers/cell_static_layer.dart';
export 'src/components/layers/cell_trail_layer.dart';
export 'src/components/layers/has_trail_support.dart';
export 'src/components/layers/layers_manager.dart';
export 'src/components/restorable_state_mixin.dart';
export 'src/components/tile_component.dart';
export 'src/components/utility/debug_component.dart';
export 'src/components/utility/on_demand_actions.dart';
export 'src/core/cell.dart';
export 'src/core/has_spatial_grid_framework.dart';
export 'src/core/spatial_grid.dart';
export 'src/tiled/map_loader.dart';
export 'src/tiled/sprite_loader.dart';
export 'src/tiled/tile_builder_context.dart';
export 'src/tiled/tile_builder_context_provider.dart';
export 'src/tiled/tile_cache.dart';
export 'src/tiled/tile_data_provider.dart';
export 'src/tiled/tileset_manager.dart';
export 'src/tiled/world_data.dart';
export 'src/tiled/world_loader.dart';
export 'src/ui/loading_progress_manager.dart';

==> flame_spatial_grid-0.8.3.tar.gz: lib/flame_spatial_grid.dart <==
library flame_spatial_grid;

export 'src/collisions/bounding_hitbox.dart';
export 'src/collisions/broadphase.dart' hide ScheduledHitboxOperation;
export 'src/collisions/collision_detection.dart';
export 'src/collisions/group_hitbox.dart';
export 'src/components/animation_global/animation_global_component.dart';
export 'src/components/animation_global/ticker_global.dart';
export 'src/components/animation_global/tickers_manager.dart';
export 'src/components/camera_wrapper.dart';
export 'src/components/has_grid_support.dart';
export 'src/components/layers/cell_layer.dart';
export 'src/components/layers/cell_static_animation_layer.dart'
    hide StaticAnimationLayerCacheEntry;
export 'src/components/layers/cell_static_layer.dart' hide ImageCacheEntry;
export 'src/components/layers/cell_trail_layer.dart';
export 'src/components/layers/has_trail_support.dart';
export 'src/components/layers/layers_manager.dart';
export 'src/components/restorable_state_mixin.dart';
export 'src/components/tile_component.dart';
export 'src/components/utility/debug_component.dart';
export 'src/components/utility/on_demand_actions.dart';
export 'src/core/cell.dart';
export 'src/core/has_spatial_grid_framework.dart';
export 'src/core/spatial_grid.dart';
export 'src/tiled/map_loader.dart';
export 'src/tiled/sprite_loader.dart';
export 'src/tiled/tile_builder_context.dart';
export 'src/tiled/tile_builder_context_provider.dart';
export 'src/tiled/tile_cache.dart';
export 'src/tiled/tile_data_provider.dart';
export 'src/tiled/tileset_manager.dart';
export 'src/tiled/world_data.dart';
export 'src/tiled/world_loader.dart';
export 'src/ui/loading_progress_manager.dart';
